=====
Cleez
=====


.. image:: https://img.shields.io/pypi/v/cleez.svg
        :target: https://pypi.python.org/pypi/cleez

.. image:: https://readthedocs.org/projects/cleez/badge/?version=latest
        :target: https://cleez.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


Abilian Cleez
=============

Simple framework for building command line applications with multiple
commands and subcommands.

Similar to Cleo, but based on the stdlib's argparse module.


* Free / open source software: Apache Software License 2.0
* Documentation: https://cleez.readthedocs.io. (nope!)


Features
--------

* TODO

Credits
-------

This package was created with Cruft_ and the `abilian/cookiecutter-abilian-python`_ project template.

.. _Cruft: https://cruft.github.io/cruft/
.. _`abilian/cookiecutter-abilian-python`: https://github.com/abilian/cookiecutter-abilian-python
